dodotable-xlsx
==============

.. image:: https://badge.fury.io/py/dodotable-xlsx.svg
   :target: https://pypi.python.org/pypi/dodotable-xlsx
   :alt: Latest PyPI version

Excel (.xlsx) exporter for dodotable_.

.. _dodotable: https://github.com/spoqa/dodotable


Changelog
---------

Version 0.1.0
~~~~~~~~~~~~~

Released on May 25, 2017.
